diff --git a/core/modules/entity_reference/lib/Drupal/entity_reference/Tests/EntityReferenceSelectionAccessTest.php b/core/modules/entity_reference/lib/Drupal/entity_reference/Tests/EntityReferenceSelectionAccessTest.php
index 9ab172b..5e01e89 100644
--- a/core/modules/entity_reference/lib/Drupal/entity_reference/Tests/EntityReferenceSelectionAccessTest.php
+++ b/core/modules/entity_reference/lib/Drupal/entity_reference/Tests/EntityReferenceSelectionAccessTest.php
@@ -32,15 +32,15 @@ function setUp() {
     $this->drupalCreateContentType(array('type' => 'article', 'name' => 'Article'));
   }
 
-  protected function assertReferencable($field, $instance, $tests, $handler_name) {
+  protected function assertReferenceable($field, $instance, $tests, $handler_name) {
     $handler = entity_reference_get_selection_handler($field, $instance);
 
     foreach ($tests as $test) {
       foreach ($test['arguments'] as $arguments) {
-        $result = call_user_func_array(array($handler, 'getReferencableEntities'), $arguments);
+        $result = call_user_func_array(array($handler, 'getReferenceableEntities'), $arguments);
         $this->assertEqual($result, $test['result'], format_string('Valid result set returned by @handler.', array('@handler' => $handler_name)));
 
-        $result = call_user_func_array(array($handler, 'countReferencableEntities'), $arguments);
+        $result = call_user_func_array(array($handler, 'countReferenceableEntities'), $arguments);
         if (!empty($test['result'])) {
           $bundle = key($test['result']);
           $count = count($test['result'][$bundle]);
@@ -113,7 +113,7 @@ public function testNodeHandler() {
     // Test as a non-admin.
     $normal_user = $this->drupalCreateUser(array('access content'));
     $GLOBALS['user'] = $normal_user;
-    $referencable_tests = array(
+    $referenceable_tests = array(
       array(
         'arguments' => array(
           array(NULL, 'CONTAINS'),
@@ -160,12 +160,12 @@ public function testNodeHandler() {
         'result' => array(),
       ),
     );
-    $this->assertReferencable($field, $instance, $referencable_tests, 'Node handler');
+    $this->assertReferenceable($field, $instance, $referenceable_tests, 'Node handler');
 
     // Test as an admin.
     $admin_user = $this->drupalCreateUser(array('access content', 'bypass node access'));
     $GLOBALS['user'] = $admin_user;
-    $referencable_tests = array(
+    $referenceable_tests = array(
       array(
         'arguments' => array(
           array(NULL, 'CONTAINS'),
@@ -189,7 +189,7 @@ public function testNodeHandler() {
         ),
       ),
     );
-    $this->assertReferencable($field, $instance, $referencable_tests, 'Node handler (admin)');
+    $this->assertReferenceable($field, $instance, $referenceable_tests, 'Node handler (admin)');
   }
 
   /**
@@ -254,7 +254,7 @@ public function testUserHandler() {
 
     // Test as a non-admin.
     $GLOBALS['user'] = $users['non_admin'];
-    $referencable_tests = array(
+    $referenceable_tests = array(
       array(
         'arguments' => array(
           array(NULL, 'CONTAINS'),
@@ -290,10 +290,10 @@ public function testUserHandler() {
         'result' => array(),
       ),
     );
-    $this->assertReferencable($field, $instance, $referencable_tests, 'User handler');
+    $this->assertReferenceable($field, $instance, $referenceable_tests, 'User handler');
 
     $GLOBALS['user'] = $users['admin'];
-    $referencable_tests = array(
+    $referenceable_tests = array(
       array(
         'arguments' => array(
           array(NULL, 'CONTAINS'),
@@ -329,7 +329,7 @@ public function testUserHandler() {
         ),
       ),
     );
-    $this->assertReferencable($field, $instance, $referencable_tests, 'User handler (admin)');
+    $this->assertReferenceable($field, $instance, $referenceable_tests, 'User handler (admin)');
   }
 
   /**
@@ -420,7 +420,7 @@ public function testCommentHandler() {
     // Test as a non-admin.
     $normal_user = $this->drupalCreateUser(array('access content', 'access comments'));
     $GLOBALS['user'] = $normal_user;
-    $referencable_tests = array(
+    $referenceable_tests = array(
       array(
         'arguments' => array(
           array(NULL, 'CONTAINS'),
@@ -454,12 +454,12 @@ public function testCommentHandler() {
         'result' => array(),
       ),
     );
-    $this->assertReferencable($field, $instance, $referencable_tests, 'Comment handler');
+    $this->assertReferenceable($field, $instance, $referenceable_tests, 'Comment handler');
 
     // Test as a comment admin.
     $admin_user = $this->drupalCreateUser(array('access content', 'access comments', 'administer comments'));
     $GLOBALS['user'] = $admin_user;
-    $referencable_tests = array(
+    $referenceable_tests = array(
       array(
         'arguments' => array(
           array(NULL, 'CONTAINS'),
@@ -472,12 +472,12 @@ public function testCommentHandler() {
         ),
       ),
     );
-    $this->assertReferencable($field, $instance, $referencable_tests, 'Comment handler (comment admin)');
+    $this->assertReferenceable($field, $instance, $referenceable_tests, 'Comment handler (comment admin)');
 
     // Test as a node and comment admin.
     $admin_user = $this->drupalCreateUser(array('access content', 'access comments', 'administer comments', 'bypass node access'));
     $GLOBALS['user'] = $admin_user;
-    $referencable_tests = array(
+    $referenceable_tests = array(
       array(
         'arguments' => array(
           array(NULL, 'CONTAINS'),
@@ -491,6 +491,6 @@ public function testCommentHandler() {
         ),
       ),
     );
-    $this->assertReferencable($field, $instance, $referencable_tests, 'Comment handler (comment + node admin)');
+    $this->assertReferenceable($field, $instance, $referenceable_tests, 'Comment handler (comment + node admin)');
   }
 }

diff --git a/core/modules/entity_reference/lib/Drupal/entity_reference/Plugin/Type/Selection/SelectionInterface.php b/core/modules/entity_reference/lib/Drupal/entity_reference/Plugin/Type/Selection/SelectionInterface.php
index 069a2cb..4379454 100644
--- a/core/modules/entity_reference/lib/Drupal/entity_reference/Plugin/Type/Selection/SelectionInterface.php
+++ b/core/modules/entity_reference/lib/Drupal/entity_reference/Plugin/Type/Selection/SelectionInterface.php
@@ -20,21 +20,21 @@
 interface SelectionInterface {
 
   /**
    * Returns a list of referencable entities.
    *
    * @return array
    *   An array of referencable entities. Keys are entity IDs and
    *   values are (safe HTML) labels to be displayed to the user.
    */
-  public function getReferencableEntities($match = NULL, $match_operator = 'CONTAINS', $limit = 0);
+  public function getReferenceableEntities($match = NULL, $match_operator = 'CONTAINS', $limit = 0);
 
   /**
    * Counts entities that are referencable by a given field.
    *
    * @return int
    *   The number of referencable entities.
    */
-  public function countReferencableEntities($match = NULL, $match_operator = 'CONTAINS');
+  public function countReferenceableEntities($match = NULL, $match_operator = 'CONTAINS');
 
   /**
    * Validates that entities can be referenced by this field.
@@ -42,7 +42,7 @@ public function countReferencableEntities($match = NULL, $match_operator = 'CONT
    * @return array
    *   An array of valid entity IDs.
    */
-  public function validateReferencableEntities(array $ids);
+  public function validateReferenceableEntities(array $ids);
 
   /**
    * Validates input from an autocomplete widget that has no ID.
@@ -20,21 +20,21 @@
 
   /**
-   * Returns a list of referencable entities.
+   * Returns a list of referenceable entities.
    *
    * @return array
@@ -20,21 +20,21 @@
    *
    * @return array
-   *   An array of referencable entities. Keys are entity IDs and
+   *   An array of referenceable entities. Keys are entity IDs and
    *   values are (safe HTML) labels to be displayed to the user.
    */
@@ -20,21 +20,21 @@
 
   /**
-   * Counts entities that are referencable by a given field.
+   * Counts entities that are referenceable by a given field.
    *
    * @return int
@@ -20,21 +20,21 @@
    *
    * @return int
-   *   The number of referencable entities.
+   *   The number of referenceable entities.
    */
diff --git a/core/modules/entity_reference/lib/Drupal/entity_reference/Plugin/entity_reference/selection/SelectionBase.php b/core/modules/entity_reference/lib/Drupal/entity_reference/Plugin/entity_reference/selection/SelectionBase.php
index ab60905..b083e0e 100644
--- a/core/modules/entity_reference/lib/Drupal/entity_reference/Plugin/entity_reference/selection/SelectionBase.php
+++ b/core/modules/entity_reference/lib/Drupal/entity_reference/Plugin/entity_reference/selection/SelectionBase.php
@@ -162,9 +162,9 @@ public static function settingsForm(&$field, &$instance) {
   }
 
   /**
-   * Implements SelectionInterface::getReferencableEntities().
+   * Implements SelectionInterface::getReferenceableEntities().
    */
-  public function getReferencableEntities($match = NULL, $match_operator = 'CONTAINS', $limit = 0) {
+  public function getReferenceableEntities($match = NULL, $match_operator = 'CONTAINS', $limit = 0) {
     $target_type = $this->field['settings']['target_type'];
 
     $query = $this->buildEntityQuery($match, $match_operator);
@@ -189,9 +189,9 @@ public function getReferencableEntities($match = NULL, $match_operator = 'CONTAI
   }
 
   /**
-   * Implements SelectionInterface::countReferencableEntities().
+   * Implements SelectionInterface::countReferenceableEntities().
    */
-  public function countReferencableEntities($match = NULL, $match_operator = 'CONTAINS') {
+  public function countReferenceableEntities($match = NULL, $match_operator = 'CONTAINS') {
     $query = $this->buildEntityQuery($match, $match_operator);
     return $query
       ->count()
@@ -199,9 +199,9 @@ public function countReferencableEntities($match = NULL, $match_operator = 'CONT
   }
 
   /**
-   * Implements SelectionInterface::validateReferencableEntities().
+   * Implements SelectionInterface::validateReferenceableEntities().
    */
-  public function validateReferencableEntities(array $ids) {
+  public function validateReferenceableEntities(array $ids) {
     $result = array();
     if ($ids) {
       $target_type = $this->field['settings']['target_type'];
@@ -219,7 +219,7 @@ public function validateReferencableEntities(array $ids) {
    * Implements SelectionInterface::validateAutocompleteInput().
    */
   public function validateAutocompleteInput($input, &$element, &$form_state, $form, $strict = TRUE) {
-    $entities = $this->getReferencableEntities($input, '=', 6);
+    $entities = $this->getReferenceableEntities($input, '=', 6);
     $params = array(
       '%value' => $input,
       '@value' => $input,
@@ -251,7 +251,7 @@ public function validateAutocompleteInput($input, &$element, &$form_state, $form
   }
 
   /**
    * Builds an EntityQuery to get referencable entities.
    *
    * @param string|null $match
    *   (Optional) Text to match the label against. Defaults to NULL.
@@ -251,7 +251,7 @@ public function validateAutocompleteInput($input, &$element, &$form_state, $form
 
   /**
-   * Builds an EntityQuery to get referencable entities.
+   * Builds an EntityQuery to get referenceable entities.
    *
    * @param string|null $match